@@ -34,7 +34,11 @@ func (resultsHandler *ResultsHandler) HandleResults(scanInfo *cautils.ScanInfo)
 	}
 
 	// TODO - get score from table
-	score := CalculatePostureScore(opaSessionObj.PostureReport)
+	var score float32 = 0
+	for i := range opaSessionObj.PostureReport.FrameworkReports {
+		score += opaSessionObj.PostureReport.FrameworkReports[i].Score
+	}
+	score /= float32(len(opaSessionObj.PostureReport.FrameworkReports))
 	resultsHandler.printerObj.Score(score)
 
 	return score
